/*
datalog.c

Datalogging Example for Adapt812DX (or Adapt812 + MX1)

*******************************************************************************
*REVISION HISTORY:
*
*DATE          REV. NO.		DESCRIPTION
*May 9,2000    0.00		    -released
*
*******************************************************************************
*/




#if defined(_HC11)
#include <hc11.h>
#elif defined(_HC12)
#include <hc12.h>
#elif defined(_HC16)
#include <hc16.h>
#else
#error "no target defined"
#endif


/* clock modes */

#define STATUS1         0x83    // clock control/status register
#define STATUS2         0x03    // clock control/status register
#define STATUS3         0x0B    // clock control/status register
                                // read date and month directly.

#define STATUS4         0x07    // clock control/status register
                                // Enable the alarm control register
                                
#define RTC_CONTROL_REG_ADDRESS 	0
#define MILLISECOND_REG_ADDRESS     1
#define SECONDS_REG_ADDRESS         2
#define MINUTES_REG_ADDRESS         3
#define HOURS_REG_ADDRESS           4
#define YEAR_DATE_REG_ADDRESS       5
#define WEEK_MONTH_REG_ADDRESS      6
#define TIMER_REG_ADDRESS           7
#define ALARM_CNTRL_REG_ADDRESS     8

#define RTC_READ_ADDRESS        0xA3    // address of rtc clock
#define RTC_WRITE_ADDRESS       0xA2    // address of rtc clock


#define SDA     0x20     // SERIAL DATA
#define SCL     0x40     // SERIAL CLOCK FOR THE DATA



/*  Operational Parameters	*/

#define _100MS		25
#define _250MS		61
#define _500MS		125
#define _1SECOND	250
#define _2SECONDS	500
#define _3SECONDS	750
#define _5SECONDS	1250
#define _10SECONDS	2500
#define _25SECONDS	6250
#define _60SECONDS	15000
#define _2MIN		30000

#define LDP128	0x1f		// last 4K page of 128K data space
#define LDP512	0x7f		// last 4K page of 512K data space
#define LPP128	0x07		// last 16K page of 128K program space
#define LPP512	0x1f		// last 16K page of 512K program space



/* frequencies in Hertz for tone generation	*/

#define TONE_2K		500		
#define TONE_1K		1000
#define TONE_440	2272
#define TONE_220	4545
#define TONE_180	3000
#define TONE_110	9090
#define TONE_60		16666


/*	Operational Constants	*/

#define TRUE    0xFF
#define FALSE   0x00
#define CR		0x0D


#define opts  	0x90	/* a/d on */
#define admask1	0x30	/* (adctl)continuous conversion, AD0 thru AD3		*/
#define admask2	0x34	/* (adctl)continuous conversion, AD4 thru AD7		*/
#define tmask	0x40	/* (tmsk2)no timer prescale, RTI enabled			*/
#define rtimsk	0x08	/* (pactl) 4.1 msec interrupt with 8 MHz xtal		*/
#define tc1msk	0x40	/*	OC2 in toggle mode								*/

#define clrmsk	0xC0	/*	mask for clearing timer flags					*/
#define ptdmsk	0x02	/*	(ddrd)portd data direction: input, except txd  	*/
#define sc2msk2 0x2C	/*	(sccr2)enable tx & rx and Rx Interrupt			*/


/* System Variables	*/

volatile unsigned char COMMAND, COMMAND_PENDING, COUNT, TIME_BUF[6], DATE_BUF[8];
volatile unsigned short TIMER, HALF_PERIOD, DATA_ADDRESS, DX,DY, PRINT_ADDRESS;
volatile unsigned char CONTINUOUS, TIME_FLAG, DATE_FLAG, PRINT_FLAG, INTERVAL_FLAG,
						BANKING,LAST_PPAGE, LAST_DPAGE, MEM_SIZE, SECONDS, MINUTES,
						HOUR, DATE, MONTH, DPAGE_PRINT, TEMP_SET;


volatile unsigned short *TIMER_SECOND, *TIMER_MINUTE ;

volatile unsigned char *DATA_ADDRESS_H, *DATA_ADDRESS_L, *LOG_FLAG, *INTERVAL_SET;

volatile unsigned char *YEAR, *YEAR_BACK1, *YEAR_BACK2, *DPAGE_BACK;



/* Required Rams variables */

/*	RTC Variables */	

volatile unsigned char spi_read, spi_write, rtc_reg_address, read_write_flag; // (read_write_flag) if bit 0 is 0 then write else read
						ack_flag;

/* time variables 

volatile unsigned char time_seconds_hundred, time_seconds, time_minutes, time_hours,
						time_days, time_months, leap_year, time_years, time_flag, 
						date_flag;
*/

#pragma	interrupt_handler RTIHandler;
#pragma	interrupt_handler SCIHandler;

void ProcessCommand(void);
void ProcessInterval(void);
void ProcessTime(void);
void ProcessDate(void);
void ShowMenu(void);
void ShowAnalog(void);
void Print_In_Dec(unsigned char i);
void Rtc_init(void);
void Time_input(void);
void Date_input(void);
void Write_time(void);
void Write_date(void);
unsigned char Read_time_mnth(void);
unsigned char Read_time_date(void);
unsigned char Read_time_hr(void);
unsigned char Read_time_min(void);
unsigned char Read_time_sec(void);
unsigned char Read_time(unsigned char x );
void Write_mod(void);
void Write_cmd(void);
void Read_cmd(void);
void Clock_bits(unsigned char x);
unsigned char Shift_bits(void);
void print_time(unsigned char x);
void Start_condition(void);
void Stop_condition(void);
void Acknowledge(void);
void Small_delay(void);
void Logging(void);
void Print_data(void);
void Put_D_T(unsigned short x);
void Write_D_T(unsigned char x, unsigned char y);

int puts(const char *s);
void putchar(char x);
unsigned char getchar(void);
void Pcad(unsigned char x, char *s);


void Temp(void);



void main(void)
	{

	INTR_OFF();			//	disable interrupts 
	
	
	/* Init. ATD */
	ATDCTL2 = 0x80 ;  	// Allow ATD
	ATDCTL5 = admask1 ;	// Set A/D to scan AD0 thru AD3 continuously	
	
		 
	/* Set up external memory control registers */
	
	PEAR = 0x04 ;	// Enable read/write signal
	MODE = 0xB0 ;   // Normal exp. narrow
	WINDEF = 0xC0 ; // Enable data & program windows
	MXAR = 0x07 ;	// Enable A16, A17, A18
	CSCTL0 = 0x30 ; // Enable CSD & CSP0
	CSCTL1 = 0x10 ; // CSD  covers lower half of memory map
	INITEE = 0x11 ; 
	
	
	RTICTL = 0x83 ; 	//enable real-time interrupt (RTI)	
						//4.096 msec interrupt with M=8 MHz
	RTIFLG = 0x80;		// Clear interrupt flag
		

	/* Initialize Serial Communication Interface */
	setbaud(BAUD9600);	//	automatically enables rx & tx	
	SC0CR2 |= 0x20 ;	// Enable rx int
	SC0CR1 = 0x0 ;	// for pooed operation
	
	DDRT = 0xFF ;	// Make port t outputs
	
	Rtc_init();			// Initialize the real-time clock/calendar chip
	
	
	MEM_SIZE = 128 ;	// Default memory size is 128K
	
	LAST_PPAGE = LPP128 ;
	LAST_DPAGE = LDP128 ;
		
		
	YEAR =	(unsigned char volatile *)(0x2000) ;
	YEAR_BACK1 = (unsigned char volatile *)(0x2001) ;
	YEAR_BACK2 = (unsigned char volatile *)(0x2002) ;
	DATA_ADDRESS_H = (unsigned char volatile *)(0x2003);
	DATA_ADDRESS_L = (unsigned char volatile *)(0x2004);
	LOG_FLAG = (unsigned char volatile *)(0x2005);
	TIMER_SECOND = (unsigned short volatile *)(0x2006);
	TIMER_MINUTE = (unsigned short volatile *)(0x2008);
	INTERVAL_SET = (unsigned char volatile *)(0x200A);
	DPAGE_BACK = (unsigned char volatile *)(0x200B);
	
	DPAGE = 0;
	DPAGE_PRINT = 0;
	COMMAND = 0 ;
	COMMAND_PENDING = FALSE ;
	CONTINUOUS = 0 ;
	TEMP_SET = 0 ;
	TIMER = 0 ;
	INTERVAL_FLAG = FALSE ;
	ack_flag = 0 ;
	PRINT_FLAG = 0;
	
	
	if(*LOG_FLAG) Logging();	// Log one time when power on, if LOG_FLAG is true.
		
	INTR_ON();			//	enable interrupts 

	ShowMenu();			// Display menu in terminal window
	
	while(1)
		{
				
		ProcessCommand();
		
			
		}
			
	}

				
	
void ProcessCommand(void)
	{
	
	unsigned char i ;
	
	
	if(COMMAND_PENDING == TRUE)
		{
			
		COMMAND_PENDING = 0;
		CONTINUOUS = 0;
		PRINT_FLAG = FALSE;
				
				
		
		if(INTERVAL_FLAG)
			{
			
			ProcessInterval();
			
			}
		
		
			
				
		else if(TIME_FLAG)
			{
		
			ProcessTime();
				
			}

		
		
		
		else if(DATE_FLAG)
			{
		
			ProcessDate();			
				
			}	

		
		
				
		else
			{
		
			putchar('\n'); 	
			COMMAND |= 0X20;
			
			switch(COMMAND)
				{  
			
								
				case 'p':
					
					PRINT_ADDRESS = 0x7010 ;
					
					PRINT_FLAG = TRUE;
					while(PRINT_FLAG){Print_data();}
					break ;
				
								
				case 'l':
			
					INTERVAL_FLAG = TRUE ;
					if(*LOG_FLAG)
						{
						puts("STATUS: LOG ON   INTERVAL TIME:");
						
						switch(*INTERVAL_SET)
				 			{
							
							case 1:
							
								puts("  1 SECOND\n");
								putchar(CR);
								break ;
						
							case 2:
						
								puts(" 10 SECONDS\n");
								putchar(CR);
								break ;
						
							case 3:
						
								puts(" 1 MINUTE\n");
								putchar(CR);
								
								break ;
						
							case 4:
						
								puts(" 10 MINUTES\n");
								putchar(CR);
								break ;
								
							case 5:
						
								puts(" 1 HOUR\n");
								putchar(CR);
								break ;
						
							case 6:
						
								puts(" 12 HOURS\n");
								putchar(CR);
								break ;
						
							case 7:
						
								puts(" 24 HOURS\n");
								putchar(CR);
								break ;
								
							default:
								{
								
								*INTERVAL_SET = 2 ;
								puts("  10 SECONDS	\n");
								putchar(CR);
								}
								
							}
						}	
				
					else
						{		
					
						puts("STATUS: LOG OFF\n");
						putchar(CR);
						
						}
					
					puts("      X: EXIT WITHOUT CHANGE");						
					putchar('\n');
					putchar(CR);
					puts("      I: INCREMENT INTERVAL TIME");						
					putchar('\n');
					putchar(CR);
					puts("<ENTER>: START NEW LOG");						
					putchar('\n');
					putchar(CR);
					
					TEMP_SET = *INTERVAL_SET ;
					
					break ;
				
								
				
				case 'r':
				
					
					ShowAnalog();
					CONTINUOUS = TRUE ;	/* set continuous a/d display flag*/
					break ;
			
				
				case 't':
			
											
					Time_input();
				
					break ;
				
				case 'd':
										
					Date_input();
						
					break ;			
					
										
					
				default:
			
					ShowMenu();
			
				}
			}
		}
	
		
	}




void ProcessInterval(void)
	{
	
	COMMAND |=0x20;
	switch(COMMAND)
		{
				
		case 'i':
				
			if(!(TEMP_SET - 0x07)) (TEMP_SET) = 0;
			else TEMP_SET += 1 ;
					
			switch(TEMP_SET)
				{
				case 0:
														
					puts("    Log: off\n");
					putchar(CR);
					break ;
					
				case 1:
					
					puts("Interval Time:? 1 Second\n");
					putchar(CR);
					break ;
							
				case 2:
						
					puts("Interval Time:? 10 Seconds\n");
					putchar(CR);
					break ;
					
				case 3:
						
					puts("Interval Time:? 1 Minute\n");
					putchar(CR);
					break ;
						
				case 4:
						
					puts("Interval Time:? 10 Minutes\n");
					putchar(CR);
					break ;
								
				case 5:
					
					puts("Interval Time:? 1 Hour\n");
					putchar(CR);
					break ;
					
				case 6:
				
					puts("Interval Time:? 12 Hours\n");
					putchar(CR);
					break ;
						
				case 7:
						
					puts("Interval Time:? 24 Hours\n");
					putchar(CR);
					break ;
						
				}
						
			break ;
	
		case 'x':
					
			putchar('\n');
			putchar(CR);
			puts("EXIT WITH NO CHANGE");
			putchar('\n');
			putchar(CR);
			INTERVAL_FLAG = FALSE ;
			ShowMenu();
				
			break ;
	
		case 0x2D:
				
			INTERVAL_FLAG = FALSE ;
			*DPAGE_BACK = 0 ;
			
			*INTERVAL_SET = TEMP_SET ;
					
			switch(*INTERVAL_SET)
				{
				case 0:
							
					putchar('\n');
					putchar(CR);
					puts("    LOG: OFF\n");
					putchar(CR);
					*LOG_FLAG = FALSE ;
					break ;
							
				case 1:
						
					putchar('\n');
					putchar(CR);
					puts("STARTING NEW LOG   INTERVAL TIME: 1 SECOND");
					putchar('\n');
					putchar(CR);
							
					*TIMER_SECOND = 245 ;
					*TIMER_MINUTE = 0 ;
						
					*DATA_ADDRESS_H = 0x70 ;
					*DATA_ADDRESS_L = 0x10 ;
							
					*DPAGE_BACK = 0 ;
					*LOG_FLAG = TRUE ;
					break ;
							
				case 2:
							
					putchar('\n');
					putchar(CR);
					puts("STARTING NEW LOG   INTERVAL TIME: 10 SECONDS");
					putchar('\n');
					putchar(CR);
						
					*TIMER_SECOND = 2455 ;
					*TIMER_MINUTE = 0 ;
				
					*DATA_ADDRESS_H = 0x70 ;
					*DATA_ADDRESS_L = 0x10 ;
							
					*DPAGE_BACK = 0 ;
					*LOG_FLAG = TRUE ;
					break ;
						
				case 3:
							
					putchar('\n');
					putchar(CR);
					puts("STARTING NEW LOG   INTERVAL TIME: 1 MINUTE");
					putchar('\n');
					putchar(CR);
					
					*TIMER_SECOND = 14650 ;
					*TIMER_MINUTE = 0 ;
					
					*DATA_ADDRESS_H = 0x70 ;
					*DATA_ADDRESS_L = 0x10 ;
					
					*DPAGE_BACK = 0 ;
					*LOG_FLAG = TRUE ;
							
					break ;
						
				case 4:
							
					putchar('\n');
					putchar(CR);
					puts("STARTING NEW LOG   INTERVAL TIME: 10 MINUTES");
					putchar('\n');
					putchar(CR);
										
					*TIMER_SECOND = 14650 ;
					*TIMER_MINUTE = 10 ;
			
					*DATA_ADDRESS_H = 0x70 ;
					*DATA_ADDRESS_L = 0x10 ;
							
					*DPAGE_BACK = 0 ;
					*LOG_FLAG = TRUE ;
							
					break ;
								
				case 5:
						
					putchar('\n');
					putchar(CR);
					puts("STARTING NEW LOG   INTERVAL TIME: 1 HOUR");
					putchar('\n');
					putchar(CR);
				
					*TIMER_SECOND = 14650 ;
					*TIMER_MINUTE = 60;
					
					*DATA_ADDRESS_H = 0x70 ;
					*DATA_ADDRESS_L = 0x10 ;
					
					*DPAGE_BACK = 0 ;
					*LOG_FLAG = TRUE ;
							
					break ;
						
				case 6:
							
					putchar('\n');
					putchar(CR);
					puts("STARTING NEW LOG   INTERVAL TIME: 12 HOURS");
					putchar('\n');
					putchar(CR);
				
					*TIMER_SECOND = 14650 ;
					*TIMER_MINUTE = 720 ;
					
					*DATA_ADDRESS_H = 0x70 ;
					*DATA_ADDRESS_L = 0x10 ;
							
					*DPAGE_BACK = 0 ;
					*LOG_FLAG = TRUE ;
							
					break ;
						
				case 7:
					
					putchar('\n');
					putchar(CR);
					puts("STARTING NEW LOG   INTERVAL TIME: 24 HOURS");
					putchar('\n');
					putchar(CR);
					
					*TIMER_SECOND = 14650;
					*TIMER_MINUTE = 1440 ;
						
					*DATA_ADDRESS_H = 0x70 ;
					*DATA_ADDRESS_L = 0x10 ;	
					
					*DPAGE_BACK = 0 ;
					*LOG_FLAG = TRUE ;
					
					break ;
						
				}
					
					
					
			ShowMenu();
					
			break ;
					
		default:
					
			putchar('\n');
			putchar(CR);
			puts("      X: EXIT WITH NO CHANGE");						
			putchar('\n');
			putchar(CR);
			puts("      I: INCREMENT INTERVAL TIME");						
			putchar('\n');
			putchar(CR);
			puts("<ENTER>: START NEW LOG");						
			putchar('\n');
			putchar(CR);
				
		}
	
	}
	
	
	
void ProcessTime(void)
	{
	
	if(!(COMMAND - 0x0D)) 
		{
			
		if((!(COUNT-1)) || (!(COUNT-3)) || (!(COUNT-5)) )
			{
			
			Time_input();
																		
			}
							
		else
			{
					
			if(COUNT>0)
				{

				HOUR = ((TIME_BUF[0]<<4)&0xF0) | (TIME_BUF[1]&0x0F) ;
				HOUR &= 0x3F ;
				Write_D_T(HOURS_REG_ADDRESS, HOUR);
				}

			if(COUNT>2)
				{
				MINUTES = ((TIME_BUF[2]<<4)&0xF0) | (TIME_BUF[3]&0x0F) ;
				MINUTES &= 0x7F ;
				Write_D_T(MINUTES_REG_ADDRESS, MINUTES);
				}
					
					
						
			TIME_FLAG = FALSE ;	
			putchar('\n');
			ShowMenu();
	
			}
					
		}
							
	else
		{
				
		COMMAND -= 0x30 ; 	
					
		switch(COUNT)
			{
				
			case 0:
				
				if(COMMAND>2)
					{
							
					Time_input();
						
					}
						
				else
					{
						
					TIME_BUF[0]=COMMAND;
					COUNT++;
					putchar(COMMAND+0x30);
							
					}
				break ;
						
			case 1:
											
				if((TIME_BUF[0]==2)&&(COMMAND>3))
					{
							
					Time_input();
						
					}
						
				else
					{
						
					TIME_BUF[1]=COMMAND;
					COUNT++;
					putchar(COMMAND+0x30);
					putchar(':');
							
					}
								
				break ;

			case 2:
		
				if(COMMAND>5)
					{
							
					Time_input();
						
					}
						
				else
					{
						
					TIME_BUF[2]=COMMAND;
					COUNT++;
					putchar(COMMAND+0x30);
					}
							
				break ;

			case 3:
								
				TIME_BUF[3]=COMMAND;
				COUNT++;
				putchar(COMMAND+0x30);
				putchar(':');		
				break ;

			case 4:
				
				if(COMMAND>5)
					{
							
					Time_input();
						
					}
						
				else
					{
						
					TIME_BUF[4]=COMMAND;
					COUNT++;
					putchar(COMMAND+0x30);
					}
							
				break ;

			case 5:
								
				TIME_BUF[5]=COMMAND;
				putchar(COMMAND+0x30);
							
				HOUR = ((TIME_BUF[0]<<4)&0xF0) | (TIME_BUF[1]&0x0F) ;
				HOUR &= 0x3F ;
				MINUTES = ((TIME_BUF[2]<<4)&0xF0) | (TIME_BUF[3]&0x0F) ;
				MINUTES &= 0x7F ;
				SECONDS = ((TIME_BUF[4]<<4)&0xF0) | (TIME_BUF[5]&0x0F) ;
				SECONDS &= 0x7F ;
						
				Write_D_T(HOURS_REG_ADDRESS, HOUR);
				Write_D_T(MINUTES_REG_ADDRESS, MINUTES);
				Write_D_T(SECONDS_REG_ADDRESS, SECONDS);
						
				TIME_FLAG = FALSE ;	
				putchar('\n');
				ShowMenu();
												
				break ;

					}

				
		}
	}	
	
	
	
	
void ProcessDate(void)
	{

	if(!(COMMAND - 0x0D)) 
		{
				
		if((!(COUNT-5)) || (!(COUNT-7)) || ((COUNT<4)&&(COUNT>0)) )
			{
			
			Date_input();
																	
			}
							
		else
			{
					
			if(COUNT>0)
				{
				DPAGE = 0;
						
				*YEAR_BACK1 = DATE_BUF[0];
				*YEAR_BACK2 = DATE_BUF[1];
				*YEAR = ((DATE_BUF[2]<<4)&0xF0) | (DATE_BUF[3]&0x0F) ;
				}	
						
			if(COUNT>4)
				{
				MONTH = ((DATE_BUF[4]<<4)&0xF0) | (DATE_BUF[5]&0x0F) ;
				MONTH &= 0x1F ;
				Write_D_T(WEEK_MONTH_REG_ADDRESS, MONTH) ;

						
				}
					
			if(COUNT>6)
				{
				DATE = ((DATE_BUF[6]<<4)&0xF0) | (DATE_BUF[7]&0x0F) ;
				DATE &= 0x3F ;
				Write_D_T(YEAR_DATE_REG_ADDRESS, DATE) ;

				}
					
						
			DATE_FLAG = FALSE ;	
			putchar('\n');
			ShowMenu();
	
			}
					
		}
							
	else
		{
			
		COMMAND -= 0x30 ; 	
					
		switch(COUNT)
			{
			
			case 0:

				if(COMMAND>2)
					{
							
					Date_input();
						
					}
				else
					{
							
					DATE_BUF[0]=COMMAND;
					COUNT++;
					putchar(COMMAND+0x30);
					}
				break ;

			case 1:
					
				if(COMMAND>9)
					{
							
					Date_input();
						
					}
				else
					{

					DATE_BUF[1]=COMMAND;
					COUNT++;
					putchar(COMMAND+0x30);
					}						
				break ;

			case 2:
					
				if(COMMAND>9)
					{
							
					Date_input();
						
					}
				else
					{

					DATE_BUF[2]=COMMAND;
					COUNT++;
					putchar(COMMAND+0x30);
					}
				break ;

			case 3:
					
				if(COMMAND>9)
					{
							
					Date_input();
						
					}
				else
					{

					DATE_BUF[3]=COMMAND;
					COUNT++;
					putchar(COMMAND+0x30);
					putchar('/');	
					}
				break ;
								

			case 4:
				
				if(COMMAND>1)
					{
							
					Date_input();
						
					}
						
				else
					{
						
					DATE_BUF[4]=COMMAND;
					COUNT++;
					putchar(COMMAND+0x30);
					}
							
				break ;

			case 5:

				if(((DATE_BUF[4]==1)&&(COMMAND>2))||((DATE_BUF[4]==0)&&(COMMAND==0)))
					{
							
					Date_input();
						
					}

				else
					{
								
					DATE_BUF[5]=COMMAND;
					COUNT++;
					putchar(COMMAND+0x30);
					putchar('/');		
					}
							
				break ;
							
							
			case 6:
				
				if(COMMAND>3)
					{
							
					Date_input();
						
					}
						
				else
					{
						
					DATE_BUF[6]=COMMAND;
					COUNT++;
					putchar(COMMAND+0x30);
					}
							
				break ;

			case 7:
							
				if(((DATE_BUF[6]==3)&&(COMMAND>1))||((DATE_BUF[6]==0)&&(COMMAND==0)))
					{
							
					Date_input();
					
					}	
						
				else
					{
									
					DATE_BUF[7]=COMMAND;
					putchar(COMMAND+0x30);
				
					DPAGE = 0 ;
					*YEAR_BACK1 = DATE_BUF[0];
					*YEAR_BACK2 = DATE_BUF[1];
					*YEAR = ((DATE_BUF[2]<<4)&0xF0) | (DATE_BUF[3]&0x0F) ;
							
							
					MONTH = ((DATE_BUF[4]<<4)&0xF0) | (DATE_BUF[5]&0x0F) ;
					MONTH &= 0x1F ;
					DATE = ((DATE_BUF[6]<<4)&0xF0) | (DATE_BUF[7]&0x0F) ;
					DATE &= 0x3F ;
						
							
					Write_D_T(WEEK_MONTH_REG_ADDRESS, MONTH) ;
					Write_D_T(YEAR_DATE_REG_ADDRESS, DATE) ;
							
					DATE_FLAG = FALSE ;	
					putchar('\n');
					ShowMenu();
							
					}
														
				break ;

			}
				
		}
	}	
	
	
	
	


void Pcad(unsigned char x, char *s)
	{
	
	unsigned char y;
	int i;
	
	for (i = 0; *s; i++, s++){putchar(*s);}

	for(i=7; i>=0; i--)
		{
		y = (x>>i) & 0x01 ;
		y += 0x30 ;				
		putchar(y);
		}
		
	/*putchar('\n');*/
	
	}	




 
void ShowMenu(void)
	{
	putchar('\n');
	putchar(CR);
	puts("\n	_________________________________________\n\n");
	putchar(CR);	
	puts(" 	812DX DATA LOGGER COMMAND MENU\n" );
	putchar(CR);
	puts("	_________________________________________\n");	
	putchar(CR);
	
	if(*LOG_FLAG)
		{					
	
		puts("	STATUS: LOG ON   INTERVAL TIME:");
	
		switch(*INTERVAL_SET)
			{
							
			case 1:
						
				puts("  1 SECOND\n");
				putchar(CR);
				break ;
						
			case 2:
						
				puts(" 10 SECONDS\n");
				putchar(CR);
				break ;
						
			case 3:
						
				puts(" 1 MINUTE\n");
				putchar(CR);
									
				break ;
						
			case 4:
						
				puts(" 10 MINUTES\n");
				putchar(CR);
				break ;
								
			case 5:
						
				puts(" 1 HOUR\n");
				putchar(CR);
				break ;
						
			case 6:
						
				puts(" 12 HOURS\n");
				putchar(CR);
				break ;
					
			case 7:
						
				puts(" 24 HOURS\n");
				putchar(CR);
				break ;
								
			default:
				{
								
				*INTERVAL_SET = 2 ;
				puts("  10 SECONDS	\n");
				putchar(CR);
				}
						
			}
		}	
				
	else
		{		
				
		puts("	STATUS: LOG OFF\n");
		putchar(CR);
						
		}
					
	puts("	L  => LOG FUNCTIONS\n");
	putchar(CR);
	puts("	P  => PRINT LOGGED DATA\n");
	putchar(CR);
	puts("	R  => SHOW REAL-TIME ANALOG VALUES\n");
	putchar(CR);	
	puts("	T  => SET TIME <hh:mm:ss> [24-hour format]\n");
	putchar(CR);
	puts("	D  => SET DATE <yyyy/mm/dd> \n\n");
	putchar(CR);


	putchar('?');
	
	}


void ShowAnalog(void)
	{
	
	ATDCTL5 = admask1 ;
	
	putchar(CR);		
	puts("  AN0=");
	Print_In_Dec(ADR0H);
	puts("  AN1=");
	Print_In_Dec(ADR1H);
	puts("  AN2=");
	Print_In_Dec(ADR2H);
	puts("  AN3=");
	Print_In_Dec(ADR3H);
		
	ATDCTL5 = admask2 ;
	
	puts("  AN4=");
	Print_In_Dec(ADR0H);
	puts("  AN5=");
	Print_In_Dec(ADR1H);
	puts("  AN6=");
	Print_In_Dec(ADR2H);
	puts("  AN7=");
	Print_In_Dec(ADR3H);
	
	putchar(CR);
	
	}



void Print_In_Dec(unsigned char i)
	{
	
	unsigned char x,y,z;
	x=0;
	y=0;
	z=0;
	
	while(i>=100)
		{
		i -= 100;
		z++;
		}	
	while(i>=10)
		{
		i -= 10 ;
		y++;
		}
	while(i>0)
		{
		i -= 1 ;
		x++;
		}
	
	putchar(z+0x30);
	putchar(y+0x30);
	putchar(x+0x30);
	
	
	}
	














void Rtc_init(void)
	{
	
	TIME_FLAG = 0 ;
	DATE_FLAG = 0 ;

	Small_delay() ;
	
	DDRS = 0x60 ; 		// Make sure bit5, and 6 are output
	PORTS = 0x60 ;		// Make sure both SDA and SCI are high
	
	Small_delay();
	Start_condition();
	
	read_write_flag = FALSE ;
	
	Clock_bits(RTC_WRITE_ADDRESS) ;		// Go start sequence
	
	Acknowledge() ;		// Get acknonledge signal from RTC
	
	Clock_bits(RTC_CONTROL_REG_ADDRESS) ;

	Acknowledge();	// Get acknowledge signal from rtc
	
	Clock_bits(0) ; 

	Acknowledge();	// Get acknowledge signal from rtc

	Stop_condition();

	}


void Date_input(void)
	{
	
	puts("	Current Date:");
	putchar(*YEAR_BACK1+0x30);
	putchar(*YEAR_BACK2+0x30);
	putchar((((*YEAR)>>4)&0x0F)+0x30); 
	putchar(((*YEAR)&0x0F)+0x30);
	putchar('/');
	print_time(Read_time_mnth());
	putchar('/');
	print_time(Read_time_date());
	
	putchar('\n');
	putchar(CR);	
	
	DATE_FLAG = TRUE ;
							
	COUNT = 0 ;
					
	puts("	New Date:");
	
	}
	
unsigned char Read_time_mnth(void)
	{
	
	unsigned char x ;
		
	x = Read_time(WEEK_MONTH_REG_ADDRESS) ;
	
	Stop_condition() ;
	
	x &= 0x1F ;
	
	return x ;
	
	}

unsigned char Read_time_date(void)
	{
	
	unsigned char x ;
		
	x = Read_time(YEAR_DATE_REG_ADDRESS) ;
	
	Stop_condition() ;
	
	x &= 0x3F ;
	
	return x ;
	
	}


	
void Time_input(void)
	{
	
	unsigned char x;
	
	puts("	Current Time:");
			
	print_time(Read_time_hr());
	
	
	putchar(':');
	
	print_time(Read_time_min());
	
	putchar(':');
	 	
	print_time(Read_time_sec());
	
	putchar('\n');
	putchar(CR);	
	
	TIME_FLAG = TRUE ;
			
				
	COUNT = 0 ;
					
	puts("	New Time:");
	
	}
	

void Write_time(void)
	{
	
	
	/* Set slave address and word address */
			
	Small_delay() ;
	
	DDRS = 0x60 ; 		// Make sure bit5, and 6 are output
	PORTS = 0x60 ;		// Make sure both SDA and SCI are high
	
	Small_delay();
	Start_condition();
	
	read_write_flag = FALSE ;
	
	Clock_bits(RTC_WRITE_ADDRESS) ;		// Go start sequence
	
	Acknowledge() ;		// Get acknonledge signal from RTC
	
	Clock_bits(RTC_CONTROL_REG_ADDRESS) ;

	Acknowledge();	// Get acknowledge signal from rtc
	
	Clock_bits(0) ; 

	Acknowledge();	// Get acknowledge signal from rtc
	
	Clock_bits(0) ;	// Set millisecond = 0

	Acknowledge();	// Get acknowledge signal from rtc
	
	Clock_bits(SECONDS) ;

	Acknowledge();	// Get acknowledge signal from rtc
	
	Clock_bits(MINUTES) ;

	Acknowledge();	// Get acknowledge signal from rtc
	
	Clock_bits(HOUR) ;

	Acknowledge();	// Get acknowledge signal from rtc
	
	Stop_condition();
	}


/* x is address, y is data */
void Write_D_T(unsigned char x, unsigned char y)
	{
	
	
	/* Set slave address and word address */
			
	Small_delay() ;
	
	DDRS = 0x60 ; 		// Make sure bit5, and 6 are output
	PORTS = 0x60 ;		// Make sure both SDA and SCI are high
	
	Small_delay();
	Start_condition();
	
	read_write_flag = FALSE ;
	
	Clock_bits(RTC_WRITE_ADDRESS) ;		// Go start sequence
	
	Acknowledge() ;		// Get acknonledge signal from RTC
	
	Clock_bits(x) ;

	Acknowledge();	// Get acknowledge signal from rtc
	
	Clock_bits(y) ; 

	Acknowledge();	// Get acknowledge signal from rtc
	
	Stop_condition();

	}
	




	
	
void Write_date(void)
	{
	
	
	/* Set slave address and word address */
			
	Small_delay() ;
	
	DDRS = 0x60 ; 		// Make sure bit5, and 6 are output
	PORTS = 0x60 ;		// Make sure both SDA and SCI are high
	
	Small_delay();
	Start_condition();
	
	read_write_flag = FALSE ;
	
	Clock_bits(RTC_WRITE_ADDRESS) ;		// Go start sequence
	
	Acknowledge() ;		// Get acknonledge signal from RTC
	
	Clock_bits(YEAR_DATE_REG_ADDRESS) ;

	Acknowledge();	// Get acknowledge signal from rtc
	
	Clock_bits(DATE) ; 

	Acknowledge();	// Get acknowledge signal from rtc
	
	Clock_bits(MONTH) ; 

	Acknowledge();	// Get acknowledge signal from rtc
	
	Stop_condition();
	
	}
	
	
	
	
	
	
	
	









	
unsigned char Read_time_hr(void)
	{
	
	unsigned char x ;
		
	x = Read_time(HOURS_REG_ADDRESS) ;
	
	Stop_condition() ;
	
	return x ;
	
	}
	
unsigned char Read_time_min(void)
	{
	
	unsigned char x ;
		
	x = Read_time(MINUTES_REG_ADDRESS) ;
	
	Stop_condition() ;
	
	return x ;
	
	}
	
unsigned char Read_time_sec(void)
	{
	
	unsigned char x ;
		
	x = Read_time(SECONDS_REG_ADDRESS) ;
	
	Stop_condition() ;
	
	return x ;
	
	}
	
unsigned char Read_time(unsigned char x )
	{
	
	unsigned char y ;
	
	/* Set slave address and word address */
	
	read_write_flag = FALSE ;
		
	Small_delay() ;
	
	DDRS = 0x60 ; 		// Make sure bit5, and 6 are output
	PORTS = 0x60 ;		// Make sure both SDA and SCI are high
	
	Small_delay();
	Start_condition();
	
	read_write_flag = FALSE ;
	
	Clock_bits(RTC_WRITE_ADDRESS) ;		// Go start sequence
	
	Acknowledge() ;		// Get acknonledge signal from RTC
	
	Clock_bits(x) ;

	Acknowledge();	// Get acknowledge signal from rtc
	
	read_write_flag = TRUE ;
	
	Small_delay() ;
	
	DDRS = 0x60 ; 		// Make sure bit5, and 6 are output
	PORTS = 0x60 ;		// Make sure both SDA and SCI are high
	
	Small_delay();
	Start_condition();
	
	Clock_bits(RTC_READ_ADDRESS);
	
	Acknowledge();	// Get acknowledge signal from rtc
	
	y = Shift_bits() ;
	
	return y ;

	}
	
void Read_cmd(void)
	{
	
	Small_delay() ;
	
	DDRS = 0x60 ; 		// Make sure bit5, and 6 are output
	PORTS = 0x60 ;		// Make sure both SDA and SCI are high
	
	Small_delay();
	Start_condition();
	
	Clock_bits(spi_read);
	
	}
	 
/*	
void Write_mod(void)
	{
	
	Small_delay() ;
	
	DDRS = 0x60 ; 		// Make sure bit5, and 6 are output
	PORTS = 0x60 ;		// Make sure both SDA and SCI are high
	
	Small_delay();
	Start_condition();
	
	read_write_flag = FALSE ;
	
	Write_cmd() ;		// Go start sequence
	Acknowledge() ;		// Get acknonledge signal from RTC
	
	Clock_bits(rtc_reg_address) ;
	
	}


	
void Write_cmd(void)
	{
	
	Clock_bits(spi_write) ;
	
	}
	
*/

void Clock_bits(unsigned char x)
	{
	
	unsigned char i,j ;
	
	i = 0x80;
	
	for(j=0; j < 8; j++)
		{
		
		if(x&i)
			{
			
			PORTS |= SDA ;	// Set SDA hi
			Small_delay();
			
			PORTS |= SCL ;	// Strobe SDA
			Small_delay();
			
			PORTS &= (~SCL) ;
			Small_delay();
			
						
			}
		else
			{
			
			PORTS &= (~SDA) ;	// Set SDA hi
			Small_delay();
			
			PORTS |= SCL ;		// Strobe SDA
			Small_delay();
			
			PORTS &= (~SCL) ;
			Small_delay();
			
			}
			
			
		i >>= 1 ;
		 
		}
	}	
	
		
		
	
	

unsigned char Shift_bits(void)
	{
	unsigned char x, y, i;
		
	y = 0 ;
	
	i = 8 ;
	
	while(i)
		{
	
		PORTS |= SCL ;	// Get data from RTC
		Small_delay();
	
		x = PORTS ;		// Read bit in
		Small_delay();
	/*Pcad(x,"shiflt");*/
	
		PORTS &= (~SCL) ;
		Small_delay();
	
		if(x & SDA)
			{
		
			y = (y<<1) | 0x01 ;
		
			}
		else
			{
		
			y = (y<<1) & 0xFE ;
	
			}			// Store bit into y
										
	
		i-- ;
		
		}
	
	return y ;
	
	}

void Start_condition(void)
	{
	
	PORTS &= (~SDA) ;	// Set SDA low to start process
	Small_delay() ;
	
	PORTS &= (~SCL) ;	// Set SCL low to satisfy start process
	Small_delay() ;
	
	}
	
void Stop_condition(void)
	{
	
	PORTS &= (~SDA) ;	// Set SDA low to start process
	Small_delay() ;
	
	PORTS |= SCL ;		// Set SCL high
	Small_delay() ;
	
	PORTS |= SDA ;		// Set SDA high
	Small_delay() ;
	
	}
	

	

void print_time(unsigned char x)
	{
		
	putchar(((x>>4)&0x0F) + 0x30) ;
	putchar((x&0x0F) + 0x30 ) ;
	
	}


void Acknowledge(void)
	{
	
	unsigned char x ;
	
	DDRS &= (~SDA) ;	// Make SDA as input
	Small_delay() ;
	
	x = PORTS ;
	
	PORTS |= SCL ;
	Small_delay() ;
	
	PORTS &= (~SCL) ;
	Small_delay() ;
	
	if(x &= SDA)
		{
		
		ack_flag = FALSE ;
		
		
		}
	else
		{
		
		ack_flag = TRUE ;
		
		if(!read_write_flag)
			DDRS |= SDA ;
		}
	 
	
	}



void Small_delay(void)
	{
	
	unsigned char i ;
	
	for(i = 0 ; i < 20 ; i++);
	
	}



void Logging(void)
	{
		
	DPAGE = *DPAGE_BACK ;	// Set the RAM page*/
	DX = *DATA_ADDRESS_H ;
	DY = *DATA_ADDRESS_L ;
	DATA_ADDRESS = ((DX<<8)&0xFF00) | (DY&0x00FF) ;
	
	*(unsigned char volatile *)DATA_ADDRESS = *YEAR_BACK1 ;
	*(unsigned char volatile *)(DATA_ADDRESS+1) = *YEAR_BACK2 ;
	*(unsigned char volatile *)(DATA_ADDRESS+2) = *YEAR ;
	*(unsigned char volatile *)(DATA_ADDRESS+3) = Read_time_mnth() ;
	*(unsigned char volatile *)(DATA_ADDRESS+4) = Read_time_date() ;
	*(unsigned char volatile *)(DATA_ADDRESS+5) = Read_time_hr() ;
	*(unsigned char volatile *)(DATA_ADDRESS+6) = Read_time_min() ;
	*(unsigned char volatile *)(DATA_ADDRESS+7) = Read_time_sec() ;
	
	ATDCTL5 = admask1 ;
	*(unsigned char volatile *)(DATA_ADDRESS+8) = ADR0H ;
	*(unsigned char volatile *)(DATA_ADDRESS+9) = ADR1H ;
	*(unsigned char volatile *)(DATA_ADDRESS+10) = ADR2H ;
	*(unsigned char volatile *)(DATA_ADDRESS+11) = ADR3H ;
		
	ATDCTL5 = admask2 ;
	
	*(unsigned char volatile *)(DATA_ADDRESS+12) = ADR0H ;
	*(unsigned char volatile *)(DATA_ADDRESS+13) = ADR1H ;
	*(unsigned char volatile *)(DATA_ADDRESS+14) = ADR2H ;
	*(unsigned char volatile *)(DATA_ADDRESS+15) = ADR3H ;

	
	
	if(DATA_ADDRESS< 0x7FD0	)
		{
		
		DATA_ADDRESS += 0x10 ;
	
		*DATA_ADDRESS_H = (DATA_ADDRESS>>8)&0x00FF;
		*DATA_ADDRESS_L = DATA_ADDRESS&0x00FF;
		
		}
	else 
		{
		
		DATA_ADDRESS = 0x7010;	// Set pointer to the beginning of the RAM page
		
		*DATA_ADDRESS_H = (DATA_ADDRESS>>8)&0x00FF;
		*DATA_ADDRESS_L = DATA_ADDRESS&0x00FF;	// Store pointer
		
		DPAGE += 1 ;
		*DPAGE_BACK += 1 ;
		
		if(DPAGE>32)
			{
			*LOG_FLAG = FALSE ;
			DPAGE=0;
			*DPAGE_BACK = DPAGE;
			}
		}
		
	DPAGE = DPAGE_PRINT ;
	
	
	
	}











void Print_data(void)
	{
	unsigned short x,y;
	unsigned char i;
	
	DPAGE = DPAGE_PRINT ;
	
	x = PRINT_ADDRESS;
		
	puts("Date: ");

	putchar(*(unsigned char volatile *)x+0x30);
	putchar(*(unsigned char volatile *)(x+1)+0x30);
	
	y = *(unsigned char volatile *)(x+2);
	
	putchar(((y>>4)&0x0F)+0x30); 
	putchar((y&0x0F)+0x30);
	putchar('/');

	y = *(unsigned char volatile *)(x+3);

	putchar(((y>>4)&0x0F)+0x30);
	putchar((y&0x0F)+0x30);
	putchar('/');
	
	y = *(unsigned char volatile *)(x+4);

	putchar(((y>>4)&0x0F)+0x30);
	putchar((y&0x0F)+0x30);
	
	
	puts("		Time: ");

	y = *(unsigned char volatile *)(x+5);
	
	putchar(((y>>4)&0x0F)+0x30); 
	putchar((y&0x0F)+0x30);
	putchar(':');
	
	y = *(unsigned char volatile *)(x+6);

	putchar(((y>>4)&0x0F)+0x30);
	putchar((y&0x0F)+0x30);
	putchar(':');
	
	y = *(unsigned char volatile *)(x+7);

	putchar(((y>>4)&0x0F)+0x30);
	putchar((y&0x0F)+0x30);
	
	putchar('\n');
	putchar(CR);	

	
	putchar(CR);		
	puts("  AN0=");
	y = *(unsigned char volatile *)(x+8);
	Print_In_Dec(y);
	puts("  AN1=");
	y = *(unsigned char volatile *)(x+9);
	Print_In_Dec(y);
	puts("  AN2=");
	y = *(unsigned char volatile *)(x+10);
	Print_In_Dec(y);
	puts("  AN3=");
	y = *(unsigned char volatile *)(x+11);
	Print_In_Dec(y);
		
	
	puts("  AN4=");
	y = *(unsigned char volatile *)(x+12);
	Print_In_Dec(y);
	puts("  AN5=");
	y = *(unsigned char volatile *)(x+13);
	Print_In_Dec(y);
	puts("  AN6=");
	y = *(unsigned char volatile *)(x+14);
	Print_In_Dec(y);
	puts("  AN7=");
	y = *(unsigned char volatile *)(x+15);
	Print_In_Dec(y);
	

	putchar('\n');
	putchar(CR);	
	putchar('\n');
	putchar(CR);	
	
			
	DX = *DATA_ADDRESS_H ;
	DY = *DATA_ADDRESS_L ;
	DATA_ADDRESS = ((DX<<8)&0xFF00) | (DY&0x00FF) ;

	
	if(DPAGE_PRINT==(*DPAGE_BACK))
		{
		
		if(PRINT_ADDRESS < (DATA_ADDRESS-0x10))
			{
		
			PRINT_ADDRESS += 0x10;
			}
		else
			{
			PRINT_FLAG = FALSE ;
			}
		
		}
	
	else
		{
	
		if(PRINT_ADDRESS< 0x7FD0	)
			{
		
			PRINT_ADDRESS += 0x10 ;
				
			}
	
		else
			{
			
			PRINT_ADDRESS = 0x7010 ;
			DPAGE_PRINT += 1 ;
			
			} 
		}
	
	
	}



void Put_D_T(unsigned short x)
	{
	unsigned short y;
		
	puts("Date: ");

	putchar(*(unsigned char volatile *)x+0x30);
	putchar(*(unsigned char volatile *)(x+1)+0x30);
	
	y = *(unsigned char volatile *)(x+2);
	
	putchar(((y>>4)&0x0F)+0x30); 
	putchar((y&0x0F)+0x30);
	putchar('/');

	y = *(unsigned char volatile *)(x+3);

	putchar(((y>>4)&0x0F)+0x30);
	putchar((y&0x0F)+0x30);
	putchar('/');
	
	y = *(unsigned char volatile *)(x+4);

	putchar(((y>>4)&0x0F)+0x30);
	putchar((y&0x0F)+0x30);
	
	
	puts("		Time: ");

	y = *(unsigned char volatile *)(x+5);
	
	putchar(((y>>4)&0x0F)+0x30); 
	putchar((y&0x0F)+0x30);
	putchar(':');
	
	y = *(unsigned char volatile *)(x+6);

	putchar(((y>>4)&0x0F)+0x30);
	putchar((y&0x0F)+0x30);
	putchar(':');
	
	y = *(unsigned char volatile *)(x+7);

	putchar(((y>>4)&0x0F)+0x30);
	putchar((y&0x0F)+0x30);
	
	putchar('\n');
	putchar(CR);	
	
	}

















int puts(const char *s)
	{
	int n;

	for (n = 0; *s; n++, s++)
		putchar(*s);
	/*putchar('\n');
	putchar(CR);*/
	return 1;
	}

void putchar(char x)
	{
	
	while(!(SC0SR1&0x80));
	SC0DRL = x;
	
	}	
/*

unsigned char getchar(void)
	{
	unsigned char x ;
	while(!(SC0SR1&0x20));
	x = SC0DRL;
	return x;
	}
*/



unsigned char getchar(void)
	{
	unsigned char x ;
	x = SC0SR1;
	x = SC0DRL;
	return x;
}


void SCIHandler(void)
	{
	
	COMMAND  = getchar();
	COMMAND_PENDING = TRUE ;
	
	}
	

void RTIHandler(void)
	{
	
	RTIFLG = 0x80 ;		/*	clear real-time interrupt flag	*/
	asm("cli");
	if(*LOG_FLAG)
		{
		
		switch(*INTERVAL_SET)
			{
			
			case 1:
				
				*TIMER_SECOND -= 1 ;
				if(!(*TIMER_SECOND))
					{
					*TIMER_SECOND = 245 ;
					Logging();
					}
				break ;			
	
			case 2:
			
				*TIMER_SECOND -= 1 ;
				if(!(*TIMER_SECOND))
					{
					*TIMER_SECOND = 2440 ;
					Logging();
					}
				break ;
			
			case 3:
				
				*TIMER_SECOND -= 1 ;
				if(!(*TIMER_SECOND))
					{
					*TIMER_SECOND = 14650 ;
					Logging();
					}
				break ;
	
			case 4:
			
				*TIMER_SECOND -= 1 ;
				if(!(*TIMER_SECOND))
					{
					
					*TIMER_MINUTE -= 1 ;
					if(!(*TIMER_MINUTE))
						{
					
					*TIMER_MINUTE = 10;
					*TIMER_SECOND = 14650 ;
					Logging();
						}
					}	
				break ;
	
			case 5:
			
				*TIMER_SECOND -= 1 ;
				if(!(*TIMER_SECOND))
					{
					
					*TIMER_MINUTE -= 1 ;
					if(!(*TIMER_MINUTE))
						{
					
					*TIMER_MINUTE = 60;
					*TIMER_SECOND = 14650 ;
					Logging();
						}
					}	
				break ;
	
			case 6:
			
				*TIMER_SECOND -= 1 ;
				if(!TIMER_SECOND)
					{
					
					*TIMER_MINUTE -= 1 ;
					if(!(*TIMER_MINUTE))
						{
					
					*TIMER_MINUTE = 720;
					*TIMER_SECOND = 14650 ;
					Logging();
						}
					}	
				break ;
	
			case 7:
			
				*TIMER_SECOND -= 1 ;
				if(!(*TIMER_SECOND))
					{
					
					*TIMER_MINUTE -= 1 ;
					if(!(*TIMER_MINUTE))
						{
					
					*TIMER_MINUTE = 1440;
					*TIMER_SECOND = 14650 ;
					Logging();
						}
					}	
				break ;
	
			default: ;
			
			}
		}
		
	
	}		
	
	
	
	



/* As is, all interrupts except reset jumps to 0xffff, which is most
 * likely not going to useful. To replace an entry, declare your function,
 * and then change the corresponding entry in the table. For example,
 * if you have a SCI handler (which must be defined with 
 * #pragma interrupt_handler ...) then in this file:
 * add
 *	extern void SCIHandler();
 * before th table.
 * In the SCI entry, change:
 *	DUMMY_ENTRY,
 * to
 *  SCIHandler, 
 */
extern void _start(void);	/* entry point in crt??.s */
extern void RTIHandler(void);
extern void SCIHandler(void);


#define DUMMY_ENTRY	(void (*)(void))0xFFFF

#ifdef _HC12
#pragma abs_address:0xffd0
#else	/* HC11 */
#pragma abs_address:0xffd6
#endif

/* change the above address if your vector starts elsewhere
 */
void (*interrupt_vectors[])(void) = 
	{
	/* to cast a constant, say 0xb600, use
	   (void (*)())0xb600
	 */
#ifdef _HC12
	/* 812A4 vectors starts at 0xff80, but most entries are not used 
	   if you use Key Wakeup H, change the start address to 0xffCE and
	   add one entry to the beginning */
	DUMMY_ENTRY,	/* BDLC */			/* Key Wakeup J */
	DUMMY_ENTRY,	/* ATD */			/* ATD */
	DUMMY_ENTRY,	/* RESERVED */		/* SCI 1 */
#endif
	SCIHandler,	/* SCI */
	DUMMY_ENTRY,	/* SPI */
	DUMMY_ENTRY,	/* PAIE */
	DUMMY_ENTRY,	/* PAO */
	DUMMY_ENTRY,	/* TOF */
	DUMMY_ENTRY,	/* TOC5 */	/* HC12 TC7 */
	DUMMY_ENTRY,	/* TOC4 */	/* TC6 */
	DUMMY_ENTRY,	/* TOC3 */	/* TC5 */
	DUMMY_ENTRY,	/* TOC2 */	/* TC4 */
	DUMMY_ENTRY,	/* TOC1 */	/* TC3 */
	DUMMY_ENTRY,	/* TIC3 */	/* TC2 */
	DUMMY_ENTRY,	/* TIC2 */	/* TC1 */
	DUMMY_ENTRY,	/* TIC1 */	/* TC0 */
	RTIHandler,	/* RTI */
	DUMMY_ENTRY,	/* IRQ */
	DUMMY_ENTRY,	/* XIRQ */
	DUMMY_ENTRY,	/* SWI */
	DUMMY_ENTRY,	/* ILLOP */
	DUMMY_ENTRY,	/* COP */
	DUMMY_ENTRY,	/* CLM */
	_start	/* RESET */
	};
#pragma end_abs_address

